import { request } from 'umi';

/** 获取  */
export async function GetStoreInfoPageAsync(data) {
     return request(`​/kitchen/api​/store-info​/store-info-page`, {
      method: 'POST',
      data: data,
      // params: { ...params },
      // ...(options || {}),
    });
  }
  export async function GetDicList(TypeCode) {
    return request(`/kitchen/api/dict-data/dic-list/${TypeCode}`, {
      method: 'Get',
    });
 }
  /** 新增  */
export async function AddStoreInfoAsync(data) {
    return request(`/kitchen/api​/store-info​/store-info`, {
     method: 'POST',
     data: data,
     // params: { ...params },
     // ...(options || {}),
   });
 }

   /** 修改  */
export async function UpdateStoreInfofoAsync(data) {
    return request(`/kitchen/api/store-info/store-infofo`, {
     method: 'put',
     data: data,
     // params: { ...params },
     // ...(options || {}),
   });
 }

   /** 启用停用  */
export async function UpdateStoreStatusAsync(data) {
  return request(`/kitchen/api/store-info/store-status`, {
   method: 'put',
   data: data,
   // params: { ...params },
   // ...(options || {}),
 });
}


   /** 删除  */
export async function DelStoreInfoAsync(data) {
    return request(`​​/kitchen/api/store-info/del-store-info`, {
     method: 'POST',
     data: data,
     // params: { ...params },

     // ...(options || {}),
   });
 }
